pub enum TxValidationResult {
Valid,
Invalid {
reason: Vec<String>,
},
Skipped {
reason: Vec<String>,
},
}Expand description
Result of validating a transaction against current node state.
Variants
Valid
Transaction is valid for current inclusion rules.
Invalid
Transaction is invalid with one or more validator reasons.
Skipped
Transaction validation was skipped with explanation.